@@ -1,12 +1,12 @@
 package App::org2wp;
 
-our $DATE = '2017-06-17'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2017-07-03'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use POSIX qw(strftime);
 
@@ -173,7 +173,7 @@ sub org2wp {
     my $org = File::Slurper::read_text($filename);
 
     require Org::To::HTML::WordPress;
-    $log->infof("Converting Org to HTML ...");
+    log_info("Converting Org to HTML ...");
     my $res = Org::To::HTML::WordPress::org_to_html_wordpress(
         source_file => $filename,
         naked => 1,
@@ -185,7 +185,7 @@ sub org2wp {
     my $title;
     if ($org =~ /^#\+TITLE:\s*(.+)/m) {
         $title = $1;
-        $log->tracef("Extracted title from Org document: %s", $title);
+        log_trace("Extracted title from Org document: %s", $title);
     } else {
         $title = "(No title)";
     }
@@ -193,7 +193,7 @@ sub org2wp {
     my $post_tags;
     if ($org =~ /^#\+TAGS?:\s*(.+)/m) {
         $post_tags = [split /\s*,\s*/, $1];
-        $log->tracef("Extracted tags from Org document: %s", $post_tags);
+        log_trace("Extracted tags from Org document: %s", $post_tags);
     } else {
         $post_tags = [];
     }
@@ -201,7 +201,7 @@ sub org2wp {
     my $post_cats;
     if ($org =~ /^#\+CATEGOR(?:Y|IES):\s*(.+)/m) {
         $post_cats = [split /\s*,\s*/, $1];
-        $log->tracef("Extracted categories from Org document: %s", $post_cats);
+        log_trace("Extracted categories from Org document: %s", $post_cats);
     } else {
         $post_cats = [];
     }
@@ -209,7 +209,7 @@ sub org2wp {
     my $postid;
     if ($org =~ /^#\+POSTID:\s*(\d+)/m) {
         $postid = $1;
-        $log->tracef("Org document already has post ID: %s", $postid);
+        log_trace("Org document already has post ID: %s", $postid);
     }
 
     require XMLRPC::Lite;
@@ -218,7 +218,7 @@ sub org2wp {
     # create categories if necessary
     my $cat_ids = {};
     {
-        $log->infof("[api] Listing categories ...");
+        log_info("[api] Listing categories ...");
         $call = XMLRPC::Lite->proxy($args{proxy})->call(
             'wp.getTerms',
             1, # blog id, set to 1
@@ -232,14 +232,14 @@ sub org2wp {
         for my $cat (@$post_cats) {
             if (my ($cat_detail) = grep { $_->{name} eq $cat } @$all_cats) {
                 $cat_ids->{$cat} = $cat_detail->{term_id};
-                $log->tracef("Category %s already exists", $cat);
+                log_trace("Category %s already exists", $cat);
                 next;
             }
             if ($dry_run) {
-                $log->infof("(DRY_RUN) [api] Creating category %s ...", $cat);
+                log_info("(DRY_RUN) [api] Creating category %s ...", $cat);
                 next;
             }
-            $log->infof("[api] Creating category %s ...", $cat);
+            log_info("[api] Creating category %s ...", $cat);
             $call = XMLRPC::Lite->proxy($args{proxy})->call(
                 'wp.newTerm',
                 1, # blog id, set to 1
@@ -257,7 +257,7 @@ sub org2wp {
     # create categories if necessary
     my $tag_ids = {};
     {
-        $log->infof("[api] Listing tags ...");
+        log_info("[api] Listing tags ...");
         $call = XMLRPC::Lite->proxy($args{proxy})->call(
             'wp.getTerms',
             1, # blog id, set to 1
@@ -271,14 +271,14 @@ sub org2wp {
         for my $tag (@$post_tags) {
             if (my ($tag_detail) = grep { $_->{name} eq $tag } @$all_tags) {
                 $tag_ids->{$tag} = $tag_detail->{term_id};
-                $log->tracef("Tag %s already exists", $tag);
+                log_trace("Tag %s already exists", $tag);
                 next;
             }
             if ($dry_run) {
-                $log->infof("(DRY_RUN) [api] Creating tag %s ...", $tag);
+                log_info("(DRY_RUN) [api] Creating tag %s ...", $tag);
                 next;
             }
-            $log->infof("[api] Creating tag %s ...", $tag);
+            log_info("[api] Creating tag %s ...", $tag);
             $call = XMLRPC::Lite->proxy($args{proxy})->call(
                 'wp.newTerm',
                 1, # blog id, set to 1
@@ -339,12 +339,12 @@ sub org2wp {
             push @xmlrpc_args, $content;
         }
         if ($dry_run) {
-            $log->infof("(DRY_RUN) [api] Create/edit post, content: %s", $content);
+            log_info("(DRY_RUN) [api] Create/edit post, content: %s", $content);
             return [304, "Dry-run"];
         }
 
-        $log->infof("[api] Creating/editing post ...");
-        $log->tracef("[api] xmlrpc method=%s, args=%s", $meth, \@xmlrpc_args);
+        log_info("[api] Creating/editing post ...");
+        log_trace("[api] xmlrpc method=%s, args=%s", $meth, \@xmlrpc_args);
         $call = XMLRPC::Lite->proxy($args{proxy})->call($meth, @xmlrpc_args);
         return [$call->fault->{faultCode}, "Can't create/edit post: ".$call->fault->{faultString}]
             if $call->fault && $call->fault->{faultCode};
@@ -354,7 +354,7 @@ sub org2wp {
     unless ($postid) {
         $postid = $call->result;
         $org =~ s/^/#+POSTID: $postid\n/;
-        $log->infof("[api] Inserting #+POSTID to %s ...", $filename);
+        log_info("[api] Inserting #+POSTID to %s ...", $filename);
         File::Slurper::write_text($filename, $org);
     }
 
@@ -376,7 +376,7 @@ App::org2wp - Publish Org document to WordPress as blog post
 
 =head1 VERSION
 
-This document describes version 0.006 of App::org2wp (from Perl distribution App-org2wp), released on 2017-06-17.
+This document describes version 0.007 of App::org2wp (from Perl distribution App-org2wp), released on 2017-07-03.
 
 =head1 FUNCTIONS
 
